Extract the Java installed version

get_java_version()

minimal_java_version

check_java_version(silent = TRUE, startup = TRUE)

Arguments

silent

Boolean to indicate if a message should be displayed.

startup

Boolean to indicate if the function is launch at the startup of the package.

Value

get_java_version() returns the current Java installed and usable version. It's an integer. minimal_java_version is the minimal Java version accepted currently by JDemetra+. check_java_version() returns TRUE or FALSE if the current version of Java is greater than or equal to the minimum required version.

Examples

print(minimal_java_version)
#> [1] 21
print(get_java_version())
#> [1] 21
check_java_version()
#> [1] TRUE